﻿param($installPath, $toolsPath, $package, $project)

$analyzersDir = Join-Path (Split-Path -Path $toolsPath -Parent) "analyzers"
if (-Not (Test-Path $analyzersDir))
{
    return
}

$analyzersPaths = Join-Path ( $analyzersDir ) * -Resolve

foreach($analyzersPath in $analyzersPaths)
{
    # Install the language agnostic analyzers.
    if (Test-Path $analyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $analyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
            }
        }
    }
}

# $project.Type gives the language name like (C# or VB.NET)
$languageFolder = ""
if($project.Type -eq "C#")
{
    $languageFolder = "cs"
}
if($project.Type -eq "VB.NET")
{
    $languageFolder = "vb"
}
if($languageFolder -eq "")
{
    return
}

foreach($analyzersPath in $analyzersPaths)
{
    # Install language specific analyzers.
    $languageAnalyzersPath = join-path $analyzersPath $languageFolder
    if (Test-Path $languageAnalyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $languageAnalyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
            }
        }
    }
}
# SIG # Begin signature block
# MIIpGwYJKoZIhvcNAQcCoIIpDDCCKQgCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCCh1voBODYpfCet
# zwmmor0XvG3ngI9/l8E/7NCzPBjyWaCCDeUwggZjMIIES6ADAgECAhMzAAADfMn2
# vO0HWa4IAAAAAAN8MA0GCSqGSIb3DQEBDAUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjMwNTExMTkwMzMyWhcNMjQwNTA4MTkwMzMyWjBjMQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMQ0wCwYDVQQDEwQuTkVU
# MIIBojANBgkqhkiG9w0BAQEFAAOCAY8AMIIBigKCAYEAzvCJrwx8/B3ia0gumPyq
# gUXY1T0AZSHoozGOgfnCwqj8I0zOeXDrPpAOhcx3VKNEf+eZYsn1TAqwgcLjCNwg
# hADahMr3CIE/YLgkANySvWJvlAVUh2O3WuC+3tBW5Vy7eL7u8iVOFxYFAUMKKloC
# aVAblZIt/cNslm4vkU07mHGPDmaq1mD9GJ9SEy7qDD9lqd0k1wLdNbdmQulaGMp0
# kgmHqiZz5FhNAHIHddS3g/XBOHgCHbAiabAOdAyIdiAuIpNo/VNAFNuYHWjiKazi
# SdUux+tcqFFS6bG2gEg39jK+HCkm5eolZOBSrXdjKrE0TI0LVBa0alxbD6NKRfax
# frI2TEp7GvUP7aXK7kLic0cSjHSG4NdyfgJ4SkRGCRUCfGE8sHrw0uqrMFruQu/l
# Xxw2X2sbYUTrgAZAD1bE01SIi34i0lSCrUgXa3u10ka+awkOPTvJXRNOhTrmSpR7
# GCktoOhmLOxXhmE9iNYem/QPqO6+cE9O3iKicNycWy/3AgMBAAGjggFzMIIBbzAf
# BgNVHSUEGDAWBgorBgEEAYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQUUqlqYUdI
# RlxDIh53GnkA2wEwPkkwRQYDVR0RBD4wPKQ6MDgxHjAcBgNVBAsTFU1pY3Jvc29m
# dCBDb3Jwb3JhdGlvbjEWMBQGA1UEBRMNNDY0MjIzKzUwMTAxNTAfBgNVHSMEGDAW
# gBRIbmTlUAXTgqoXNzcitW2oynUClTBUBgNVHR8ETTBLMEmgR6BFhkNodHRwOi8v
# d3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0EyMDExXzIw
# MTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUwUzBRBggrBgEFBQcwAoZFaHR0cDov
# L3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0EyMDEx
# XzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcNAQEMBQADggIB
# AA5IRhzUa2Q4e5oQ403ZmEbAF9VU6Wz3WlX23FW8p0nCXxeMzdQPzQ3Rzia+hVPo
# rVrxWAmibnx6Dtzoe7A+x2+E2VqyU6FecVMcZSon76Bc8OAflrbDmPQgdObJiRK/
# g0NKL27YW2BZGOV/JqD2vyS8FFS/8zwhI7Z2qd4uJCElxMv3mYVym3sl/ab5vbnA
# zpLkE+9XiyB6lkxDAYkcEA2D7DZhR+BDjfSadkeDvSIjpX6swRw9bqMVp/0H/n6+
# 9eXDjJpuvfZbeh+Szg7FNfwdV9Es7y4r+N0I4Nfa8Bpl6Htg121Maoyw6Ejoo5b4
# gBCtSe8RuJE+Y+q+AWMAfR41Sv/PL9e3yDEGtqcVB0zWBW/ntpT8cy0rwvy2kBPR
# mNyH/jETagelV1wg/GMhKUdAkgvs20QjT9Y80Dtp8SJSPwJm3GD2K/LL+Et36LgI
# 5+EV6tpazGTAz6gopilYkkVBOAlnyQeGg5NXGjEyx4R9RqXOgvQL4wewN2wyflVD
# DcsK6iqmeEbq+c3RMw2xs3J0F+VwGUAI4/P5LpA1+nravQlhZfAFu1Ez7cD10e0P
# ieqv9mO0IAbwZ3FTbbQPbjQGZTn9NlE4cfA8uXgB+aSL+6iAa+cXJ3X3AUccbzSA
# Hk32ux0pSzGE74KpTO5B66tMsrN/qUrKM5/BhDYgyk3XMIIHejCCBWKgAwIBAgIK
# YQ6Q0gAAAAAAAzANBgkqhkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNV
# BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
# c29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlm
# aWNhdGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1OTA5WhcNMjYwNzA4MjEw
# OTA5WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
# BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgwJgYD
# VQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAyMDExMIICIjANBgkqhkiG
# 9w0BAQEFAAOCAg8AMIICCgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGfQhsqa+la
# UKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDIOdUBFDFC04kNeWSHfpRgJGyvnkmc
# 6Whe0t+bU7IKLMOv2akrrnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13YxC4D
# dato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT+OPeBw3VXHmlSSnnDb6gE3e+
# lD3v++MrWhAfTVYoonpy4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nk
# kDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXDOW5kf1O6nA+tGSOEy/S6
# A4aN91/w0FK/jJSHvMAhdCVfGCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmd
# X4jiJV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA4bysAoJf28AVs70b1FVL
# 5zmhD+kjSbwYuER8ReTBw3J64HLnJN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zd
# sGbiwZeBe+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ecXL93KCjx7W3DKI8sj0A3
# T8HhhUSJxAlMxdSlQy90lfdu+HggWCwTXWCVmj5PM4TasIgX3p5O9JawvEagbJjS
# 4NaIjAsCAwEAAaOCAe0wggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1UdDgQWBBRI
# bmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMAQTAL
# BgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToCMZBD
# uRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBLhklodHRwOi8vY3JsLm1pY3Jv
# c29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
# MDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEFBQcwAoZCaHR0cDovL3d3
# dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
# MDNfMjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQBgjcuAzCBgzA/BggrBgEF
# BQcCARYzaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1h
# cnljcHMuaHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBnAGEAbABfAHAAbwBsAGkA
# YwB5AF8AcwB0AGEAdABlAG0AZQBuAHQALiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn
# 8oalmOBUeRou09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+vj/oCso7
# v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzSGksc8zxCi1LQsP1r4z4HLimb5j0b
# pdS1HXeUOeLpZMlEPXh6I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6VoCo/
# KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu5a8n7dDd8w6vmSiXmE0OPQvy
# CInWH8MyGOLwxS3OW560STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBp
# mLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38cbxV9Rad25UAqZaPDXVJi
# hsMdYzaXht/a8/jyFqGaJ+HNpZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYb
# BL7fQccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmAH9AAKcWxm6U/RXceNcbS
# oqKfenoi+kiVH6v7RyOA9Z74v2u3S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sL
# gOppO6/8MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF670EKsT/7qMykXcGhiJtX
# cVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJUnMTDXpQzTGCGowwghqIAgEBMIGVMH4x
# CzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
# b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01p
# Y3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTECEzMAAAN8yfa87QdZrggAAAAA
# A3wwDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQw
# HAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEILHG
# 5OyijfDOM5bxiJFmyVasy7d752HLA4qfvHm7QzF9MEIGCisGAQQBgjcCAQwxNDAy
# oBSAEgBNAGkAYwByAG8AcwBvAGYAdKEagBhodHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20wDQYJKoZIhvcNAQEBBQAEggGAdL/T7gbk/FiuCa5sBKniHt3/iisXPRfTom/p
# f+hJ34dz1Qp0r0QDfYSURXf7lLlbCm04uoGlmZ0FS2RJ9Ujog7ryIVm11xtKc97n
# 2AP7KAhcGyI3Ntz7z48MYx8eZGpV5piKOjsGZS2cOCv8/aIybJJujL2ShjwxJvig
# pqPXVbXuORdClYeKa0FTu55Ab+jZ+Zp+JJCuNhhswpj+gjv/AHhIFXN9hCU7lusV
# af9eXZG3pr7zyU5XI+4mG9InpyOgyhaJ3mlb8c4CaB8qBxOU469/H9VgHD2H2eIk
# KPMSOAMuZgq8Rk/gLc0R0YZrLawztZv0m7MpQwLwlSZ05Kne7Rk1KHi6mKZ84XYQ
# X4OCnG1sy0J8GyzK+f8t1Qy9POzrCbT1briWSno/hYb9ESgjL43li3LkTsnJTvEP
# qeMdfQdnADg/Uot4M/VvNom4Xv5nBEL109avNy3P/93nz4gdAgMLFKJIW/fs5t7Q
# N0oOqpTXU9VpiLBxe/iI33eBi2x8oYIXljCCF5IGCisGAQQBgjcDAwExgheCMIIX
# fgYJKoZIhvcNAQcCoIIXbzCCF2sCAQMxDzANBglghkgBZQMEAgEFADCCAVIGCyqG
# SIb3DQEJEAEEoIIBQQSCAT0wggE5AgEBBgorBgEEAYRZCgMBMDEwDQYJYIZIAWUD
# BAIBBQAEIBwGmQQiCQN0i4E8O700rEE4WkigM3ZDcNqD+CdOlTzSAgZlevh+4rAY
# EzIwMjMxMjE0MTkwMzQ2LjY2MVowBIACAfSggdGkgc4wgcsxCzAJBgNVBAYTAlVT
# MRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
# ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJTAjBgNVBAsTHE1pY3Jvc29mdCBBbWVy
# aWNhIE9wZXJhdGlvbnMxJzAlBgNVBAsTHm5TaGllbGQgVFNTIEVTTjo4RDAwLTA1
# RTAtRDk0NzElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZaCC
# EewwggcgMIIFCKADAgECAhMzAAABzVUHKufKwZkdAAEAAAHNMA0GCSqGSIb3DQEB
# CwUAMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQH
# EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNV
# BAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwMB4XDTIzMDUyNTE5MTIw
# NVoXDTI0MDIwMTE5MTIwNVowgcsxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
# aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
# cG9yYXRpb24xJTAjBgNVBAsTHE1pY3Jvc29mdCBBbWVyaWNhIE9wZXJhdGlvbnMx
# JzAlBgNVBAsTHm5TaGllbGQgVFNTIEVTTjo4RDAwLTA1RTAtRDk0NzElMCMGA1UE
# AxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZTCCAiIwDQYJKoZIhvcNAQEB
# BQADggIPADCCAgoCggIBANM4ItVLaOYRY6rHPKBbuzpguabb2mO8D4KHpUvseVMv
# zJS3dnQojNNrY78e+v9onNrWoRWSWrs0+I6ukEAjPrnstXHARzgHEmK/oHrxrwNC
# IXpYAUU1ordYeLtN/FGeouiGA3Pu9k/KVlBfv3mvwxC9fnq7COP9HiFedHs1rguW
# 7iZayaX/CnpUmoK7Fme72NfippTGeByt8VPv7O+VcKXAtqHafR4YqdrV06M6DIrT
# SNirm+3Ovk1n6pXGprD0OYSyP29+piR9BmvLYk7nCaBdfv07Hs8sxR+pPj7zDkmR
# 1IyhffZvUPpwMpZFS/mqOJiHij9r16ET8oCRRaVI9tsNH9oac8ksAY/LaoD3tgIF
# 54gmNEpRGB0+WETk7jqQ6O7ydgmci/Fu4LZCnaPHBzqsP0zo+9zyxkhxDXRgplVg
# qz3hg9KWSHBfC21tFj6NmdCIObZkWMfxI97UjoRFx95hfXMJiMTN3BZyb58VmaUk
# D0dBbtkkCY4QI4218rbwREQQTnLOr5PdAxU+GIR8SGBxiyHQN6haJgawOIoS5L4U
# SUwzJPjnr5TZlFraFtFD3tBxu9oB3o5VAundNCo0S7R6zlmrTCDYIAN/5ApBH9jr
# 58aCT2ok0lbcy7vvUq2G4+U18qyzQHXOHTFrXI3ioLfOgT1SrpPyvsbf861IWazj
# AgMBAAGjggFJMIIBRTAdBgNVHQ4EFgQUoZP5pjZpmsEAlUhmHmSJyiR81ZowHwYD
# VR0jBBgwFoAUn6cVXQBeYl2D9OXSZacbUzUZ6XIwXwYDVR0fBFgwVjBUoFKgUIZO
# aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jcmwvTWljcm9zb2Z0JTIw
# VGltZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSkuY3JsMGwGCCsGAQUFBwEBBGAwXjBc
# BggrBgEFBQcwAoZQaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0
# cy9NaWNyb3NvZnQlMjBUaW1lLVN0YW1wJTIwUENBJTIwMjAxMCgxKS5jcnQwDAYD
# VR0TAQH/BAIwADAWBgNVHSUBAf8EDDAKBggrBgEFBQcDCDAOBgNVHQ8BAf8EBAMC
# B4AwDQYJKoZIhvcNAQELBQADggIBAFKobemkohT6L8QzDC2i2jGcp/DRJf/dPXoQ
# 9uPCwAiZY5nmcsBtq2imXzMVjzjWBvl6IvWPzWHgOISJe34EmAcgDYsiEqFKxx3v
# 2gxuvrfUOISp/1fktlHdXcohiy1Tcrt/kOTu1uhu4e77p9gz+A7HjiyBFTthD5hN
# ge+/yTiYye6JqElGVT8Xa9q9wdTm6FeLTvwridJEA+dbJfuBWLqJUwEFQXjzbeg8
# XOcRwe6ntU0ZG0Z7XG+eUx3UK7LFy0zx3+irJOzHCUkAzkX+UPGcRahLMCRp3Wda
# +RoB4xXv7f0ileG5/0bfFt98qLIGePdxB6IDhLFLAJ2fHTREGVdLqv20YNr+j1FL
# TUU4AHMqQ/kIEOmbjCkp0hTvgq0EfawTlBhifuWJhZmvZ/9T6CFOZ04Q4+RcRxfz
# Ufh1ElTbxOP+BRl3AvzXFqHwqf5wHu8z8ezf8ny0XXdk8/7w21fe+7g2tyEcMliC
# M6L7Um5J/7iOkX+kQQ9en0C6yLOZKaQEriJVPs3BW1GdLW2zyoAYcY+DYc9rhva7
# 2Z655Sio1W0yFu6YjXL531mROE1cFfPZoi1PYL30MzdPepioBSa8pSvJVKkwtWmx
# 7iN7lY3pVWUIMUpYVEfbTZjERVaxnlto30JqoJsJLQRruz04UtoQzl82f2bmzr2U
# P96RxbapMIIHcTCCBVmgAwIBAgITMwAAABXF52ueAptJmQAAAAAAFTANBgkqhkiG
# 9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAO
# BgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEy
# MDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IDIw
# MTAwHhcNMjEwOTMwMTgyMjI1WhcNMzAwOTMwMTgzMjI1WjB8MQswCQYDVQQGEwJV
# UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
# ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGlt
# ZS1TdGFtcCBQQ0EgMjAxMDCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIB
# AOThpkzntHIhC3miy9ckeb0O1YLT/e6cBwfSqWxOdcjKNVf2AX9sSuDivbk+F2Az
# /1xPx2b3lVNxWuJ+Slr+uDZnhUYjDLWNE893MsAQGOhgfWpSg0S3po5GawcU88V2
# 9YZQ3MFEyHFcUTE3oAo4bo3t1w/YJlN8OWECesSq/XJprx2rrPY2vjUmZNqYO7oa
# ezOtgFt+jBAcnVL+tuhiJdxqD89d9P6OU8/W7IVWTe/dvI2k45GPsjksUZzpcGkN
# yjYtcI4xyDUoveO0hyTD4MmPfrVUj9z6BVWYbWg7mka97aSueik3rMvrg0XnRm7K
# MtXAhjBcTyziYrLNueKNiOSWrAFKu75xqRdbZ2De+JKRHh09/SDPc31BmkZ1zcRf
# NN0Sidb9pSB9fvzZnkXftnIv231fgLrbqn427DZM9ituqBJR6L8FA6PRc6ZNN3SU
# HDSCD/AQ8rdHGO2n6Jl8P0zbr17C89XYcz1DTsEzOUyOArxCaC4Q6oRRRuLRvWoY
# WmEBc8pnol7XKHYC4jMYctenIPDC+hIK12NvDMk2ZItboKaDIV1fMHSRlJTYuVD5
# C4lh8zYGNRiER9vcG9H9stQcxWv2XFJRXRLbJbqvUAV6bMURHXLvjflSxIUXk8A8
# FdsaN8cIFRg/eKtFtvUeh17aj54WcmnGrnu3tz5q4i6tAgMBAAGjggHdMIIB2TAS
# BgkrBgEEAYI3FQEEBQIDAQABMCMGCSsGAQQBgjcVAgQWBBQqp1L+ZMSavoKRPEY1
# Kc8Q/y8E7jAdBgNVHQ4EFgQUn6cVXQBeYl2D9OXSZacbUzUZ6XIwXAYDVR0gBFUw
# UzBRBgwrBgEEAYI3TIN9AQEwQTA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNy
# b3NvZnQuY29tL3BraW9wcy9Eb2NzL1JlcG9zaXRvcnkuaHRtMBMGA1UdJQQMMAoG
# CCsGAQUFBwMIMBkGCSsGAQQBgjcUAgQMHgoAUwB1AGIAQwBBMAsGA1UdDwQEAwIB
# hjAPBgNVHRMBAf8EBTADAQH/MB8GA1UdIwQYMBaAFNX2VsuP6KJcYmjRPZSQW9fO
# mhjEMFYGA1UdHwRPME0wS6BJoEeGRWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9w
# a2kvY3JsL3Byb2R1Y3RzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNybDBaBggr
# BgEFBQcBAQROMEwwSgYIKwYBBQUHMAKGPmh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
# bS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3J0MA0GCSqGSIb3
# DQEBCwUAA4ICAQCdVX38Kq3hLB9nATEkW+Geckv8qW/qXBS2Pk5HZHixBpOXPTEz
# tTnXwnE2P9pkbHzQdTltuw8x5MKP+2zRoZQYIu7pZmc6U03dmLq2HnjYNi6cqYJW
# AAOwBb6J6Gngugnue99qb74py27YP0h1AdkY3m2CDPVtI1TkeFN1JFe53Z/zjj3G
# 82jfZfakVqr3lbYoVSfQJL1AoL8ZthISEV09J+BAljis9/kpicO8F7BUhUKz/Aye
# ixmJ5/ALaoHCgRlCGVJ1ijbCHcNhcy4sa3tuPywJeBTpkbKpW99Jo3QMvOyRgNI9
# 5ko+ZjtPu4b6MhrZlvSP9pEB9s7GdP32THJvEKt1MMU0sHrYUP4KWN1APMdUbZ1j
# dEgssU5HLcEUBHG/ZPkkvnNtyo4JvbMBV0lUZNlz138eW0QBjloZkWsNn6Qo3GcZ
# KCS6OEuabvshVGtqRRFHqfG3rsjoiV5PndLQTHa1V1QJsWkBRH58oWFsc/4Ku+xB
# Zj1p/cvBQUl+fpO+y/g75LcVv7TOPqUxUYS8vwLBgqJ7Fx0ViY1w/ue10CgaiQuP
# Ntq6TPmb/wrpNPgkNWcr4A245oyZ1uEi6vAnQj0llOZ0dFtq0Z4+7X6gMTN9vMvp
# e784cETRkPHIqzqKOghif9lwY1NNje6CbaUFEMFxBmoQtB1VM1izoXBm8qGCA08w
# ggI3AgEBMIH5oYHRpIHOMIHLMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGlu
# Z3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
# cmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1lcmljYSBPcGVyYXRpb25zMScw
# JQYDVQQLEx5uU2hpZWxkIFRTUyBFU046OEQwMC0wNUUwLUQ5NDcxJTAjBgNVBAMT
# HE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2WiIwoBATAHBgUrDgMCGgMVAGip
# 96bYorO5FmMhJiJ8aiVU53IEoIGDMIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNV
# BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
# c29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAg
# UENBIDIwMTAwDQYJKoZIhvcNAQELBQACBQDpJXb/MCIYDzIwMjMxMjE0MTI0MzQz
# WhgPMjAyMzEyMTUxMjQzNDNaMHYwPAYKKwYBBAGEWQoEATEuMCwwCgIFAOkldv8C
# AQAwCQIBAAIBPQIB/zAHAgEAAgITtzAKAgUA6SbIfwIBADA2BgorBgEEAYRZCgQC
# MSgwJjAMBgorBgEEAYRZCgMCoAowCAIBAAIDB6EgoQowCAIBAAIDAYagMA0GCSqG
# SIb3DQEBCwUAA4IBAQCJckFs0piN2G/wpwvGfkvZCiN4X9k3un3Xakv7Kau0zz01
# 45Ylv+fP4Tw76PKQ0GaKScGO3tzvl+mCcRYW6yVuFTlcll61KfXP+ACh5lX4Dm+Q
# OXfQF+drofd/kjRn6pk1Wh5jQ2QC/qovVnmxERBJ3VhJ/h8bt6YqiHCWjAZSWwJw
# sVuP2pOuw7YJGsH1xJwNvPw8Txk1qb3a/5EjNS3wT/PaM0HrqWuvVwbdp0aU0Y2V
# 6xWRCMnXpt6IMvPSB1YUFrYsrsrcCf5tsT9GoiM4bQPOlxaL3Ox+9582apH1sp7J
# RywANIOQ1+c0aDrZ9OIq3Wy5/D+cI31/zgI77O+4MYIEDTCCBAkCAQEwgZMwfDEL
# MAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
# bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWlj
# cm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTACEzMAAAHNVQcq58rBmR0AAQAAAc0w
# DQYJYIZIAWUDBAIBBQCgggFKMBoGCSqGSIb3DQEJAzENBgsqhkiG9w0BCRABBDAv
# BgkqhkiG9w0BCQQxIgQgc7YSQ/XxY5Pz4JMczClrQz+KMkwCTm/k2XzfyWL6s64w
# gfoGCyqGSIb3DQEJEAIvMYHqMIHnMIHkMIG9BCDiZqX4rVa9T2RoL0xHU6UrVHOh
# jYeyza6EASsKVEaZCjCBmDCBgKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpX
# YXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQg
# Q29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAy
# MDEwAhMzAAABzVUHKufKwZkdAAEAAAHNMCIEIINnWjFQEfyQQ9u5TWUVhG7dHfyP
# cp443j3EWnNXQu5HMA0GCSqGSIb3DQEBCwUABIICAIfC05YfEddbZPHqf+8WHkDq
# acZ9V+SXsvfg63MnXVByxA53QNzA9O6vH4muJaiNEgLWSwFCxTQWpeizcv9FTDu8
# 4MlA7kokFmq8Js/cNR8IT/hXhHum7KYLcgDk+D97y45bzVFyDO/1IQuFUkJFcxHy
# CVOwvT1FH4tfzzcIU+ekkW2uEFv2ua/uFpuEBOF77+LWsSes2ytGfiOshXoMT6Sh
# f/87x9rZMglThnzsPMJP1aprJgs8bbC/67Me/6u6B/JiP3aGNNTqGJfGYj3F/yG5
# qsoTcpqsO5YWnL/CKFiAe23U/t/OyYgWZHtakyI+MNQ99zr9MXXMSgY8YF0U+Wld
# YzmnxPz3wOqcpBvuKA66u+lDADogG237IPSwT8jrvgDFC2buBB8IXO2Wj0eql42F
# WAm+T/HNaetnlLhGeyOtHUHFDt58JhNG56uVsyqn7H8NPutucQEqXoaJMEywIEvH
# 15xxlezyXaFxvHL55mIFU9YQnW12XW/SgiNl5QSNbWS8SX5axQJ+NI9zB+m+6CSd
# ybJdRHVAKH1R8w67+jjFfKJ2NjokkzZfWE1nOjf8PJvYFrdWbmX1F3vbZvh6bvjx
# EtG6dwml4EhrGHl5c2zjv1kL5z0Ltlyk5HZSE6cxDoqwozHvZh2W/pIb2iEHkmd6
# NefR1Eu9IkodTsI8VX90
# SIG # End signature block
